import { createWebHashHistory, createRouter } from 'vue-router'

import Layout from '../layout/index.vue'
import HomeView from '../views/home/index.vue'
import HouseHome from '../views/house/home.vue'
import AssetsHome from '../views/assets/home.vue'
import PlanningHome from '../views/planning/home.vue'
import PersonalHome from '../views/personal/home.vue'
import HouseWorkbench from '../views/house/workbench/index.vue'
import Consignor from '../views/house/consignor.vue'
import Certificate from '../views/house/certificate.vue'
import BaseInfo from '../views/house/baseInfo.vue'
import Assumption from '../views/house/assumption.vue'
import EntityInfo from '../views/house/entityInfo.vue'

const routes = [
  {
    path:'/',
    redirect:'/home/index'
  },
  {
    path: '/home',
    component: Layout,
    name: 'index',
    meta: {
      title: '首页'
    },
    children: [
      {
        path: 'index',
        component: HomeView,
        name: 'homeIndex',
      },
      {
        path: 'house',
        component: HouseHome,
        name: 'houseIndex',
        meta: {
          title:'房地产首页'
        }
      },
      {
        path: 'assets',
        component: AssetsHome,
        name: 'assetsIndex'
      },
      {
        path: 'planning',
        component: PlanningHome,
        name: 'planningIndex'
      },
      {
        path: 'personal',
        component: PersonalHome,
        name: 'personalIndex'
      },
      {
        path: 'houseWorkbench',
        component: HouseWorkbench,
        name: 'houseWorkbench',
        meta: {
          title:'房地产工作台'
        },
        children: [
          {
            path: 'consignor',
            component: Consignor,
            name: 'consignor',
            meta: {
              title:'委托人信息'
            },
          },
          {
            path: 'certificate',
            component: Certificate,
            name: 'certificate',
            meta: {
              title:'权属资料'
            },
          },
          {
            path: 'baseInfo',
            component: BaseInfo,
            name: 'baseInfo',
            meta: {
              title:'项目基本信息'
            },
          },
          {
            path: 'assumption',
            component: Assumption,
            name: 'assumption',
            meta: {
              title:'假设条件'
            },
          },
          {
            path: 'entityInfo',
            component: EntityInfo,
            name: 'entityInfo',
            meta: {
              title:'实物状况'
            },
          }
        ]
      }
    ]
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  routes,
})

export default router